package
Version:
v1.0.2
Opens a new window with list of versions in this module.
Published: Apr 20, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func ComponentProperty() []byte
组件属性配置
用于通用属性和定制属性
通用属性 1. 排除 2. 包含
定制属性 组件特有的属性
func DialogFilter() []byte
弹窗过滤
SetIcon 设置应用程序图标
函数签名不能修改
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.